@@ -6,7 +6,6 @@ import logging
 
 from .transform import with_geo, with_bbl, to_csv, stream_files_from_zip, extract_csv_from_zip, skip_fields
 from .transform import hpd_registrations_address_cleanup, hpd_contacts_address_cleanup
-from .dof_parser import parse_dof_file
 from .datasets import datasets
 
 def ecb_violations(dataset):
@@ -17,6 +16,14 @@ def dob_violations(dataset):
     return with_bbl(to_csv(dataset.files[0].dest), borough='boro')
 
 
+def dof_exemption_classification_codes(dataset):
+    return to_csv(dataset.files[0].dest)
+
+
+def dof_exemptions(dataset):
+    return with_bbl(to_csv(dataset.files[1].dest), borough='boro')
+
+
 def _pluto(dataset):
     """
     Handles importing of all pluto versions,
@@ -77,9 +84,7 @@ def hpd_contacts(dataset):
 
 
 def dof_sales(dataset):
-    for f in dataset.files:
-        for row in with_bbl(parse_dof_file(f.dest)):
-            yield row
+    return with_bbl(to_csv(dataset.files[0].dest))
 
 
 def dobjobs(dataset):
@@ -113,6 +118,7 @@ def oath_hearings(dataset):
                     block='violationlocationblockno',
                     lot='violationlocationlotno')
 
+
 def pad_adr(dataset):
     pad_generator = with_bbl(to_csv(extract_csv_from_zip(
         dataset.files[0].dest, 'bobaadr.txt')), borough='boro')
@@ -129,7 +135,20 @@ def j51_exemptions(dataset):
 def marshal_evictions(dataset, schema):
     dest_file = next(filter(lambda f: schema['table_name'] in f.dest, dataset.files))
     _to_csv = to_csv(dest_file.dest)
-    return _to_csv
+    if 'skip' in schema:
+        return skip_fields(_to_csv, [s.lower() for s in schema['skip']])
+    else:
+        return _to_csv
+
+
+def nycha_bbls(dataset, schema):
+    dest_file = next(filter(lambda f: schema['table_name'] in f.dest, dataset.files))
+    _to_csv_with_bbl = with_bbl(to_csv(dest_file.dest))
+    return _to_csv_with_bbl
+
+
+def hpd_litigations(dataset):
+    return to_csv(dataset.files[0].dest)
 
 
 def hpd_vacateorders(dataset):
